#include <cmath>
#include <iostream>
#include <vector>
#include <algorithm>
#include <string>
#include <set>
#include <map>
#include <list>
#include <time.h>
#include <math.h>
#include <random>
#include <deque>
#include <queue>
#include <cassert>
#include <unordered_map>
#include <unordered_set>
#include <iomanip>
#include <bitset>
#include <sstream>
#include <chrono>
#include <cstring>

using namespace std;

typedef long long ll;

#ifdef ONPC
    mt19937 rnd(228);
#else
    mt19937 rnd(chrono::high_resolution_clock::now().time_since_epoch().count());
#endif


class Blossom {
	public:
		const static int N = 2e4 + 10;
		int mate[N], n, ret;
        vector <int> G[N];
        void init()
        {
            for (int i = 0; i < N; i++) G[i].clear();
        }
		int run(int n)
        {
			this->n = n;
			memset(mate, -1, sizeof(mate[0]) * n);
			for (int i = 0; i < n; i++) if (mate[i] == -1) aug(i, G);
			for (int i = ret = 0; i < n; i++) ret += (mate[i] > i);
			return ret;
		}
        void add_edge(int a, int b)
        {
            G[a].push_back(b);
            G[b].push_back(a);
        }
	private:
		int next[N], dsu[N], mark[N], vis[N];
		queue<int> Q;
		int get(int x) {
			return (x == dsu[x]) ? x : (dsu[x] = get(dsu[x]));
		}
		void merge(int a, int b) {
			dsu[get(a)] = get(b);
		}
		int lca(int x, int y) {
			static int t = 0;
			++t;
			for (; ; swap(x, y)) if (x != -1) {
				if (vis[x = get(x)] == t) return x;
				vis[x] = t;
				x = (mate[x] != -1) ? next[mate[x]] : -1;
			}
		}
		void group(int a, int p) {
			for (int b, c; a != p; merge(a, b), merge(b, c), a = c) {
				b = mate[a], c = next[b];
				if (get(c) != p) next[c] = b;
				if (mark[b] == 2) mark[b] = 1, Q.push(b);
				if (mark[c] == 2) mark[c] = 1, Q.push(c);
			}
		}
		void aug(int s, const vector<int> G[]) {
			for (int i = 0; i < n; i++) next[i] = vis[i] = -1, dsu[i] = i, mark[i] = 0;
			while (!Q.empty()) Q.pop();
			Q.push(s);
			mark[s] = 1;
			while (mate[s] == -1 && !Q.empty()) {
				int x = Q.front();
				Q.pop();
				for (int y : G[x]) {
					if (y != mate[x] && get(x) != get(y) && mark[y] != 2) {
						if (mark[y] == 1) {
							int p = lca(x, y);
							if (get(x) != p) next[x] = y;
							if (get(y) != p) next[y] = x;
							group(x, p);
							group(y, p);
						} else if (mate[y] == -1) {
							next[y] = x;
							for (int j = y, k, l; j != -1; j = l) {
								k = next[j];
								l = mate[k];
								mate[j] = k;
								mate[k] = j;
							}
							break;
						} else {
							next[y] = x;
							Q.push(mate[y]);
							mark[mate[y]] = 1;
							mark[y] = 2;
						}
					}
				}
			}
		}
} T;


int dx[] = {0, 1, 0, -1};
int dy[] = {1, 0, -1, 0};

int main()
{
#ifdef ONPC
    freopen("a.in", "r", stdin);
#endif
    ios::sync_with_stdio(0);
    cin.tie(0);
    T.init();
    int n, m;
    cin >> n >> m;
    vector <string> s(n);
    vector <vector <int> > ind(n, vector <int> (m));
    vector <vector <int> > ind_a(n, vector <int> (m));
    vector <vector <int> > ind_b(n, vector <int> (m));
    int sz = 0;
    for (int i = 0; i < n; i++)
    {
        cin >> s[i];
        for (int j = 0; j < m; j++)
        {
            if (s[i][j] == '.')
            {
                ind[i][j] = sz++;
            }
            else
            {
                ind_a[i][j] = sz++;
                ind_b[i][j] = sz++;
            }
        }
    }
    int cost = 0;
    for (int i = 0; i < n; i++)
    {
        for (int j = 0; j < m; j++)
        {
            if (s[i][j] != '.')
            {
                T.add_edge(ind_a[i][j], ind_b[i][j]);
                for (int t = 0; t < 4; t++)
                {
                    if (0 <= i + dx[t] && i + dx[t] < n && 0 <= j + dy[t] && j + dy[t] < m && s[i + dx[t]][j + dy[t]] == '.')
                    {
                        if (s[i][j] == '+' || t % 2 == 0) T.add_edge(ind_a[i][j], ind[i + dx[t]][j + dy[t]]);
                        if (s[i][j] == '+' || t % 2 == 1) T.add_edge(ind_b[i][j], ind[i + dx[t]][j + dy[t]]);
                    }
                }
                cost++;
            }
        }
    }
    T.run(sz);
    auto ans = s;
    for (int i = 0; i < n; i++)
    {
        for (int j = 0; j < m; j++)
        {
            if (s[i][j] != '.')
            {
                if (T.mate[ind_a[i][j]] != -1 && T.mate[ind_b[i][j]] != -1 && T.mate[ind_a[i][j]] != ind_b[i][j])
                {
                    set <char> c;
                    for (int x = -2; x <= 2; x++)
                    {
                        for (int y = -2; y <= 2; y++)
                        {
                            if (0 <= i + x && i + x < n && 0 <= j + y && j + y < m && 'a' <= ans[i + x][j + y] && ans[i + x][j + y] <= 'z')
                            {
                                c.insert(ans[i + x][j + y]);
                            }
                        }
                    }
                    char ch = 'a';
                    while (c.count(ch)) ch++;
                    ans[i][j] = ch;
                    for (int t = 0; t < 4; t++)
                    {
                        if (0 <= i + dx[t] && i + dx[t] < n && 0 <= j + dy[t] && j + dy[t] < m && s[i + dx[t]][j + dy[t]] == '.' && (T.mate[ind_a[i][j]] == ind[i + dx[t]][j + dy[t]] || T.mate[ind_b[i][j]] == ind[i + dx[t]][j + dy[t]]))
                        {
                            ans[i + dx[t]][j + dy[t]] = ch;
                        }
                    }
                }
            }
        }
    }
    for (int i = 0; i < n; i++) cout << ans[i] << '\n';
}
