#include <cmath>
#include <iostream>
#include <vector>
#include <algorithm>
#include <string>
#include <set>
#include <map>
#include <list>
#include <time.h>
#include <math.h>
#include <random>
#include <deque>
#include <queue>
#include <cassert>
#include <unordered_map>
#include <unordered_set>
#include <iomanip>
#include <bitset>
#include <sstream>
#include <chrono>

using namespace std;

typedef long long ll;

#ifdef ONPC
    mt19937 rnd(228);
#else
    mt19937 rnd(chrono::high_resolution_clock::now().time_since_epoch().count());
#endif

const int N = 3e5 + 7;
const ll inf = 1e18 + 7;

ll pref[N];
int L[N], R[N];

struct data
{
    ll mn, mx;
    int add;
    int invs;
};

data t[4 * N];

void upd(int v, int x)
{
    t[v].mn += x;
    t[v].mx += x;
    t[v].add += x;
}

void push(int v)
{
    upd(v * 2 + 1, t[v].add);
    upd(v * 2 + 2, t[v].add);
    t[v].add = 0;
}

data operator + (const data &a, const data &b)
{
    data ret;
    ret.mn = min(a.mn, b.mn);
    ret.mx = max(a.mx, b.mx);
    ret.add = 0;
    ret.invs = (a.mn < b.mx) + a.invs + b.invs;
    return ret;
}

void upd(int v, int l, int r, int tl, int tr, int x)
{
    if (tl >= r || tr <= l)
    {
        return;
    }
    if (tl >= l && tr <= r)
    {
        upd(v, x);
    }
    else
    {
        int tm = (tl + tr) / 2;
        push(v);
        upd(v * 2 + 1, l, r, tl, tm, x);
        upd(v * 2 + 2, l, r, tm, tr, x);
        t[v] = t[v * 2 + 1] + t[v * 2 + 2];
    }
}

void relax(int v, int l, int r, int i, bool u)
{
    if (r - l == 1)
    {
        if (!u)
        {
            t[v].mn = t[v].add - (L[i] ? pref[L[i] - 1] : 0);
            t[v].mx = (t[v].add + 1) - pref[R[i]];
            t[v].invs = (t[v].mn < t[v].mx);
        }
        else
        {
            t[v].mn = inf;
            t[v].mx = -inf;
            t[v].invs = 0;
        }
    }
    else
    {
        int m = (l + r) / 2;
        push(v);
        if (i < m)
        {
            relax(v * 2 + 1, l, m, i, u);
        }
        else
        {
            relax(v * 2 + 2, m, r, i, u);
        }
        t[v] = t[v * 2 + 1] + t[v * 2 + 2];
    }
}

int main()
{
#ifdef ONPC
    freopen("a.in", "r", stdin);
#endif
    ios::sync_with_stdio(0);
    cin.tie(0);
    int n, T;
    cin >> n >> T;
    for (int i = 0; i < T; i++)
    {
        int a;
        cin >> a;
        pref[i] += a;
        if (i) pref[i] += pref[i - 1];
    }
    vector <pair <int, int> > p;
    for (int i = 0; i < n; i++)
    {
        int x;
        cin >> L[i] >> R[i] >> x;
        L[i]--, R[i]--;
        p.push_back({x, i});
    }
    for (int i = 0; i < 4 * n; i++)
    {
        t[i].mn = inf;
        t[i].mx = -inf;
        t[i].add = 0;
        t[i].invs = 0;
    }
    sort(p.rbegin(), p.rend());
    ll ans = 0;
    for (auto c : p)
    {
        upd(0, c.second, n, 0, n, 1);
        relax(0, 0, n, c.second, 0);
        if (t[0].invs)
        {
            upd(0, c.second, n, 0, n, -1);
            relax(0, 0, n, c.second, 1);
        }
        else
        {
            ans += c.first;
        }
    }
    cout << ans << '\n';
}
